Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(591)

Unified Diff: content/common/set_process_title_linux.h

Issue 11225045: Move a bunch of content\common code into the content namespace. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/set_process_title_linux.h
===================================================================
--- content/common/set_process_title_linux.h (revision 163359)
+++ content/common/set_process_title_linux.h (working copy)
@@ -5,6 +5,7 @@
#ifndef CONTENT_COMMON_SET_PROCESS_TITLE_LINUX_H_
#define CONTENT_COMMON_SET_PROCESS_TITLE_LINUX_H_
+namespace content {
// Set the process title that will show in "ps" and similar tools. Takes
// printf-style format string and arguments. After calling setproctitle()
// the original main() argv[] array should not be used. By default, the
@@ -13,10 +14,12 @@
//
// This signature and naming is to be compatible with most other Unix
// implementations of setproctitle().
-void setproctitle(const char* fmt, ...);
+void SetProcTitle(const char* fmt, ...);
-// Initialize state needed for setproctitle() on Linux. Pass the argv pointer
-// from main() to setproctitle_init() before calling setproctitle().
-void setproctitle_init(const char** main_argv);
+// Initialize state needed for SetProcTitle() on Linux. Pass the argv pointer
+// from main() to SetProcTitleInit() before calling SetProcTitle().
+void SetProcTitleInit(const char** main_argv);
+} // namespace content
+
#endif // CONTENT_COMMON_SET_PROCESS_TITLE_LINUX_H_

Powered by Google App Engine
This is Rietveld 408576698